==> progamification-0.0.90.tar.gz: lib/src/controllers/leader_board.dart <==
import 'package:progamification/src/models/leader_board.dart';
import 'package:progamification/src/models/rewards.dart';
import 'package:progamification/src/services/leaderboard.service.dart';
import 'package:get/get.dart';

class LeaderBoardController extends GetxController {
  var leaderBoardData = <LeaderBoardModel>[].obs;

  var userRewards = {}.obs;

  String sasToken = "";
  LeaderBoardService leaderBoardService = Get.find();

  LeaderBoardController();

  Future<void> getData(String userId, String applicationId) async {
    leaderBoardService
        .getLeaderBoard(userId, applicationId)
        .then(setData)
        .catchError((err) {
      throw Exception(err);
    });
  }

  void setData(data) {
    var boardData = data['data'];
    var leaderBoard = (boardData['Items'] as List)
        .map((e) => LeaderBoardModel.fromJson(e))
        .toList();
    leaderBoardData.value = leaderBoard;
  }

  Future<void> getRewards(String userId, String applicationId) async {
    leaderBoardService
        .getUserRewards(userId, applicationId)
        .then(setUserRewards);
  }

  void setUserRewards(data) {
    var rewardsData = data['data'];
    var rewards = RewardsModel.fromJson(rewardsData);
    userRewards.value = rewards.toJson();
  }

  LeaderBoardModel getLeaderBoardData(String userId) {
    return leaderBoardData.firstWhere((element) => element.userId == userId);
  }

  int? getCurrentUserIndex(String userId) {
    int index =
        leaderBoardData.indexWhere((element) => element.userId == userId);
    return index != -1 ? index : null;
  }
}

==> progamification-1.3.0.tar.gz: lib/src/controllers/leader_board.dart <==
import 'package:progamification/src/models/leader_board.dart';
import 'package:progamification/src/models/rewards.dart';
import 'package:progamification/src/services/leaderboard.service.dart';
import 'package:get/get.dart';

class LeaderBoardController extends GetxController {
  var leaderBoardData = <LeaderBoardModel>[].obs;

  String sasToken = "";
  LeaderBoardService leaderBoardService = Get.find();

  LeaderBoardController();

  Future<void> getData(String userId, String applicationId) async {
    await leaderBoardService
        .getLeaderBoard(userId, applicationId)
        .then(setData)
        .catchError((err) {
      throw Exception(err);
    });
  }

  Future<void> setData(data) async {
    dynamic boardData = data['data'];
    List<LeaderBoardModel> leaderBoard = (boardData['Items'] as List)
        .map((e) => LeaderBoardModel.fromJson(e))
        .toList();
    leaderBoardData.value = leaderBoard;
  }

  Future<Map<String, dynamic>> getRewards(
      String userId, String applicationId) async {
    var data = await leaderBoardService.getUserRewards(userId, applicationId);
    dynamic rewardsData = data['data'];
    RewardsModel rewards = RewardsModel.fromJson(rewardsData);
    return rewards.toJson();
  }

  LeaderBoardModel getLeaderBoardData(String userId) {
    return leaderBoardData.firstWhere((element) => element.userId == userId);
  }

  int? getCurrentUserIndex(String userId) {
    int index =
        leaderBoardData.indexWhere((element) => element.userId == userId);
    return index != -1 ? index : null;
  }
}
